@@ -31,29 +31,18 @@
 setConstructorS3("AromaMicroarrayDataFile", function(...) {
   extend(GenericDataFile(...), c("AromaMicroarrayDataFile", 
                                                uses("FileCacheKeyInterface"))
-  );
+  )
 }, abstract=TRUE)
 
 
-setMethodS3("getPlatform", "AromaMicroarrayDataFile", abstract=TRUE);
+setMethodS3("getPlatform", "AromaMicroarrayDataFile", abstract=TRUE)
 
 
-setMethodS3("getChipType", "AromaMicroarrayDataFile", abstract=TRUE);
+setMethodS3("getChipType", "AromaMicroarrayDataFile", abstract=TRUE)
 
  
 setMethodS3("isAverageFile", "AromaMicroarrayDataFile", function(this, ...) {
-  name <- getName(this);
-  res <- (regexpr("^[.]average-", name) != -1);
-  res;
+  name <- getName(this)
+  res <- (regexpr("^[.]average-", name) != -1)
+  res
 })
-
-
-############################################################################
-# HISTORY:
-# 2012-11-16
-# o CLEANUP: Dropped (get|set)Label() for AromaMicroarrayDataFile.
-# 2009-11-18
-# o Added isAverageFile() for AromaMicroarrayDataFile.
-# 2007-09-16
-# o Created from AffymetrixFile.R.
-############################################################################
