@@ -23,20 +23,10 @@
 #*/########################################################################### 
 setConstructorS3("AromaUnitFracBCnBinaryFile", function(...) {
   extend(AromaUnitSignalBinaryFile(...), "AromaUnitFracBCnBinaryFile"
-  );
+  )
 })
 
 
 setMethodS3("extractRawAlleleBFractions", "AromaUnitFracBCnBinaryFile", function(this, ..., clazz=RawAlleleBFractions) {
-  extractRawGenomicSignals(this, ..., clazz=clazz);
+  extractRawGenomicSignals(this, ..., clazz=clazz)
 })
-
-
-
-############################################################################
-# HISTORY:
-# 2009-05-17
-# o Added extractRawAlleleBFractions() for AromaUnitFracBCnBinaryFile.
-# 2008-05-11
-# o Created.
-############################################################################
