@@ -23,13 +23,13 @@
 # @author
 #*/###########################################################################
 setConstructorS3("AromaUnitGenotypeCallSet", function(...) {
-  extend(AromaUnitCallSet(...), "AromaUnitGenotypeCallSet");
+  extend(AromaUnitCallSet(...), "AromaUnitGenotypeCallSet")
 })
 
 
 setMethodS3("byPath", "AromaUnitGenotypeCallSet", function(static, ..., pattern=".*,genotypes[.]acf$") {
   suppressWarnings({
-    NextMethod("byPath", pattern=pattern);
+    NextMethod("byPath", pattern=pattern)
   })
 }, protected=TRUE)
 
@@ -37,11 +37,11 @@ setMethodS3("byPath", "AromaUnitGenotypeCallSet", function(static, ..., pattern=
 setMethodS3("byName", "AromaUnitGenotypeCallSet", function(static, name, tags=NULL, ..., chipType=NULL, pattern=".*,genotypes[.]acf$") {
   suppressWarnings({
     path <- findByName(static, name=name, tags=tags, chipType=chipType,
-                                           ..., mustExist=TRUE);
+                                           ..., mustExist=TRUE)
   })
 
   suppressWarnings({
-    byPath(static, path=path, ..., pattern=pattern);
+    byPath(static, path=path, ..., pattern=pattern)
   })
 }, static=TRUE)
 
@@ -51,59 +51,50 @@ setMethodS3("extractGenotypeMatrix", "AromaUnitCallSet", function(this, ..., dro
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
 
-  verbose && enter(verbose, "Extracting genotypes across all arrays");
-  verbose && cat(verbose, "Number of files: ", length(this));
+  verbose && enter(verbose, "Extracting genotypes across all arrays")
+  verbose && cat(verbose, "Number of files: ", length(this))
 
-  res <- NULL;
+  res <- NULL
   for (kk in seq_along(this)) {
-    df <- this[[kk]];
+    df <- this[[kk]]
     verbose && enter(verbose, sprintf("File #%d ('%s') of %d",
-                                kk, getName(df), length(this)));
+                                kk, getName(df), length(this)))
 
     values <- extractGenotypeMatrix(df, ..., drop=FALSE,
-                                            verbose=less(verbose,10));
-    verbose && str(verbose, values);
+                                            verbose=less(verbose,10))
+    verbose && str(verbose, values)
 
     if (kk == 1) {
-      dim <- dim(values);
-      dim[length(dim)] <- length(this);
-      dimnames <- list(rownames(values), getNames(this));
-      res <- array(values[1], dim=dim, dimnames=dimnames);
+      dim <- dim(values)
+      dim[length(dim)] <- length(this)
+      dimnames <- list(rownames(values), getNames(this))
+      res <- array(values[1], dim=dim, dimnames=dimnames)
     }
 
-    res[,kk] <- values;
+    res[,kk] <- values
 
-    verbose && exit(verbose);
+    verbose && exit(verbose)
   } # for (kk ...)
 
   # Drop singletons?
   if (drop) {
-    res <- drop(res);
+    res <- drop(res)
   }
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  res;
+  res
 })
 
 
 
 setMethodS3("extractGenotypes", "AromaUnitGenotypeCallSet", function(this, ...) {
-  extractGenotypeMatrix(this, ...);
+  extractGenotypeMatrix(this, ...)
 })
-
-
-############################################################################
-# HISTORY:
-# 2009-01-10
-# o Fixed extractGenotypesMatrix().
-# 2008-12-09
-# o Created.
-############################################################################
