@@ -23,14 +23,14 @@
 # @author
 #*/###########################################################################
 setConstructorS3("UnitNamesFile", function(...) {
-  extend(UnitAnnotationDataFile(...), "UnitNamesFile");
+  extend(UnitAnnotationDataFile(...), "UnitNamesFile")
 })
 
 
-setMethodS3("getUnitNames", "UnitNamesFile", abstract=TRUE);
+setMethodS3("getUnitNames", "UnitNamesFile", abstract=TRUE)
 
 setMethodS3("nbrOfUnits", "UnitNamesFile", function(this, ...) {
-  length(getUnitNames(this));
+  length(getUnitNames(this))
 })
 
 
@@ -69,45 +69,22 @@ setMethodS3("nbrOfUnits", "UnitNamesFile", function(this, ...) {
 setMethodS3("indexOf", "UnitNamesFile", function(this, pattern=NULL, names=NULL, ...) {
   # Arguments 'pattern' & 'names':
   if (!is.null(pattern) && !is.null(names)) {
-    throw("Only one of arguments 'pattern' and 'names' can be specified.");
+    throw("Only one of arguments 'pattern' and 'names' can be specified.")
   }
 
   if (is.null(pattern) && is.null(names)) {
-    throw("Either argument 'names' or 'pattern' must be specified.");
+    throw("Either argument 'names' or 'pattern' must be specified.")
   }
 
   if (!is.null(pattern)) {
     if (length(pattern) != 1) {
-      throw("If specified, argument 'pattern' must be a single string. Did you mean to use argument 'names'?");
+      throw("If specified, argument 'pattern' must be a single string. Did you mean to use argument 'names'?")
     }
-    pattern <- Arguments$getRegularExpression(pattern);
-    idxs <- grep(pattern, getUnitNames(this));
+    pattern <- Arguments$getRegularExpression(pattern)
+    idxs <- grep(pattern, getUnitNames(this))
   } else if (!is.null(names)) {
-    idxs <- match(names, getUnitNames(this));
+    idxs <- match(names, getUnitNames(this))
   }
 
-  idxs;
+  idxs
 })
-
-
-############################################################################
-# HISTORY:
-# 2009-07-08
-# o CORRECTNESS: Added missing abstract getUnitNames().
-# o CLEAN UP: Now UnitNamesFile inherits from UnitAnnotationDataFile.
-# 2009-05-18
-# o Now indexOf() for UnitNamesFile assert that exactly one of the 'pattern'
-#   and 'names' arguments is given.  It also gives an informative error
-#   message if 'pattern' is a vector.
-# 2009-02-10
-# o Added static byChipType() to UnitNamesFile.
-# o Added a sanity check to getAromaUgpFile() of UnitNamesFile,
-#   which asserts that the number of units in the located UGP file match
-#   that of the data file. 
-# 2009-01-26
-# o Added getAromaUgpFile() to UnitNamesFile.
-# 2008-07-21
-# o Renamed UnitNamesInterface to UnitNamesFile.
-# 2008-05-18
-# o Created.
-############################################################################
