@@ -55,16 +55,11 @@ if (require("DNAcopy")) {
 }
 
 
-if (require("mpcbs")) {
-  fit <- local({
-    ## WORKAROUND: There's a _R_CHECK_LENGTH_1_LOGIC2_ bug in
-    ## mpcbs::mpcbs.mbic().  Until fixed, we need to disable this check
-    ## while calling segmentByMPCBS().
-    ovalue <- Sys.getenv("_R_CHECK_LENGTH_1_LOGIC2_")
-    on.exit(Sys.setenv("_R_CHECK_LENGTH_1_LOGIC2_"=ovalue))
-    ovalue <- Sys.setenv("_R_CHECK_LENGTH_1_LOGIC2_"="warn,verbose")
-    segmentByMPCBS(cn)
-  })
+## WORKAROUND: There's a _R_CHECK_LENGTH_1_LOGIC2_ bug in
+## mpcbs::mpcbs.mbic().  Until fixed, if ever, we cannot
+## call segmentByMPCBS() here. /HB 2022-11-10
+if (isTRUE(Sys.getenv("R_CHECK_FULL")) && require("mpcbs")) {
+  fit <- segmentByMPCBS(cn)
   cnr <- extractCopyNumberRegions(fit)
   print(cnr)
   drawLevels(cnr, col="white", lwd=6)
